@@ -17,7 +17,10 @@ from genomoncology.parse.doctypes import is_header, is_annotated_call
 from specd import create_app
 
 from genomoncology import kms
-from genomoncology.cli.utils import filter_del_lines_from_load_annotations
+from genomoncology.cli.utils import (
+    filter_del_lines_from_load_annotations,
+    filter_bnd_cpx_ctx_lns_from_load_annotations,
+)  # noqa E501
 from genomoncology.parse import (
     DocType,
     is_not_skipped_call,
@@ -43,7 +46,7 @@ DEFAULT_SPECD_PATH = os.path.join(
     os.path.dirname(__file__), "../../gosdk/specs/"
 )
 
-VERSION = "0.9.17"
+VERSION = "0.9.18"
 COPYRIGHT = "Copyright: GenomOncology, LLC"
 
 
@@ -624,6 +627,49 @@ def match_therapies(state, diseases):
     ]
 
 
+@gocli.command()
+@click.option(
+    "--delete-if-exists",
+    "-d",
+    help="Delete if exists, before recalculating annotation.",
+    type=bool,
+    multiple=False,
+    default=False,
+)
+@click.option(
+    "--region_match_tolerance",
+    "-rmt",
+    help="Region match tolerance",
+    default=0.5,
+)
+@click.option(
+    "--cnv_match_tolerance", "-cmt", help="CNV match tolerance", default=0.33
+)
+@options.pass_state
+@options.build_option
+def sv_match(
+    state, delete_if_exists, region_match_tolerance, cnv_match_tolerance
+):
+    """Calls the annotations sv matching endpoint."""
+
+    create_function = kms.create_sync_processor
+    sdk_function = kms.annotations.sync_annotate_sv_match
+
+    return [
+        filter(is_not_skipped_call),
+        partition_all(99_999_999),
+        create_function(
+            state,
+            sdk_function,
+            delete_if_exists=delete_if_exists,
+            build=state.build,
+            region_match_tolerance=region_match_tolerance,
+            cnv_match_tolerance=cnv_match_tolerance,
+        ),
+        concat,
+    ]
+
+
 @gocli.command()
 @options.pass_state
 @click.option(
@@ -882,9 +928,21 @@ def load_features(state, workers):
 @options.pass_state
 def load_annotations(state, timeout, data_set, data_set_version, workers):
     """Loads variant objects into annotations core."""
+
+    """ In a previous ticket there was logic that was implemented to remove
+     any lines in the vcf file that have <DEL> the reasoning was due to the
+     fact that we do not yet have the ability to process them. As of kms-4333
+     the gnomad_sv dataset will require the ability to process these types and
+    therefore we created 2 options for the building of the pipeline.
+    If the dataset is gnomad_sv then build the pipeline without filtering out
+    the <DEL>'s otherwise filter out the <DEL>."""
+    if data_set == "gnomad_sv":
+        filter_step = filter_bnd_cpx_ctx_lns_from_load_annotations
+    else:
+        filter_step = filter_del_lines_from_load_annotations
     return [
         filter(is_not_skipped_call),
-        filter(filter_del_lines_from_load_annotations),
+        filter(filter_step),
         transformers.create_transformer(output_type=data_set, state=state),
         filter(None),
         partition_all(state.batch_size),
