@@ -150,6 +150,43 @@ async def async_annotate(
     return annotated_calls
 
 
+@curry
+def sync_annotate_sv_match(
+    calls,
+    sdk=None,
+    delete_if_exists=False,
+    build=GRCh37,
+    region_match_tolerance=0.5,
+    cnv_match_tolerance=0.33,
+):
+    batch = []
+    seen_bnd_ids = []
+    for record in calls:
+        if record["__type__"] != "HEADER":
+            if record["mutation_type"] == "BND":
+                if record["id"] not in seen_bnd_ids:
+                    batch.append(parse_bnd_sv_hashes(record, calls))
+                    seen_bnd_ids.append(record["id"])
+                    seen_bnd_ids.append(record["mate_id"][0])
+            else:
+                batch.append(record["sv_hash"])
+
+    annotations = (
+        sdk.call_with_retry(
+            sdk.annotations.post_annotations_sv_match,
+            batch=batch,
+            delete_if_exists=delete_if_exists,
+            build=build,
+            region_match_tolerance=region_match_tolerance,
+            cnv_match_tolerance=cnv_match_tolerance,
+        )
+        if batch
+        else None
+    )
+
+    return annotations.get("results", [])
+
+
 @curry
 def sync_annotate(
     data,
@@ -499,6 +536,29 @@ def get_annotation_bundle_version(sdk):
     return annotation_bundle_version.annotation_bundle_version
 
 
+def parse_bnd_sv_hashes(record, data):
+    for item in data:
+        if item.get("id", None) == record["mate_id"][0]:
+            chr = record["chr_info"]
+            fusion = item["chr_info"]
+            extra_info = record["extra_info"]
+
+            rel_orien = ""
+            same = "(?:% s)" % "|".join(
+                ["](chr)?([0-9]+|[xyXY]):[0-9]+]\w", "\w\[(chr)?([0-9]+|[xyXY]):[0-9]+\["]
+            )
+            reverse = "(?:% s)" % "|".join(
+                ["\[(chr)?([0-9]+|[xyXY]):[0-9]+\[\w", "\w](chr)?([0-9]+|[xyXY]):[0-9]+]"]
+            )
+
+            if re.match(same, record["alt"]):
+                rel_orien = "|REL_ORIEN=same_orientation"
+            elif re.match(reverse, record["alt"]):
+                rel_orien = "|REL_ORIEN=reverse_orientation"
+
+            return f"{chr}|{fusion}|{extra_info}{rel_orien}"
+
+
 class AnnBundleVersionAssertionError(AssertionError):
     pass
 
