@@ -35,6 +35,7 @@ class DocType(Enum):
 
     # Annotation Data Sets
     GNOMAD = "GNOMAD"
+    GNOMAD_SV = "GNOMAD_SV"
     HGMD = "HGMD"
     HGMD_GENE_LIST = "HGMD_GENE_LIST"
     BAYLOR_WGL = "BAYLOR_WGL"
@@ -60,6 +61,7 @@ class DocType(Enum):
     MITO_TRNA = "MITO_TRNA"
     MTDB = "MTDB"
     CLINGEN_DOSAGE = "CLINGEN_DOSAGE"
+    SV_HASH = "SV_HASH"
 
     def is_a(self, a_dict):
         try:
