@@ -26,6 +26,8 @@ from . import (
     mito_trna,
     mtdb,
     clingen_dosage,
+    gnomad_sv,
+    sv_hash,
 )
 
 __all__ = (
@@ -56,5 +58,7 @@ __all__ = (
     "secondary_findings_genes",
     "mito_trna",
     "mtdb",
+    "gnomad_sv",
     "clingen_dosage",
+    "sv_hash",
 )
